/*
    lm78.h - Header file for the Linux sensor programs
    Copyright (c) 1997, 1998  Alexander Larsson <alla@lysator.liu.se>,
    Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock <phil@netroedge.com>.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Heavily patched by Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock
   (phil@Stimpy.netroedge.com). */

#ifndef LM78_H
#define LM78_H

#include <asm/io.h>

#define LM78_BASE 0x290
#define LM78_EXTENT 0x8
#define LM78_ADDRESS_REG (LM78_BASE + 0x5)
#define LM78_DATA_REG (LM78_BASE + 0x6)

#define LM78_BUSY ( inb_p( LM78_ADDRESS_REG ) & (1<<7) )

#define LM78_DUMMY 0x20

#define LM78_READ(addr) ({ \
outb_p((addr),LM78_ADDRESS_REG); \
inb_p(LM78_DATA_REG); \
})

#define LM78_WRITE(addr,x)  \
outb_p( (addr), LM78_ADDRESS_REG ); \
outb_p( (x), LM78_DATA_REG )

/* address constants within LM78 RAM */
#define LM78_IN0 0x20     
#define LM78_IN1 0x21     
#define LM78_IN2 0x22     
#define LM78_IN3 0x23     
#define LM78_IN4 0x24     
#define LM78_IN5 0x25
#define LM78_IN6 0x26     
#define LM78_TEMPERATURE 0x27
#define LM78_FAN1 0x28
#define LM78_FAN2 0x29
#define LM78_FAN3 0x2A
#define LM78_IN0_MAX 0x2b
#define LM78_IN0_MIN 0x2c
#define LM78_IN1_MAX 0x2d
#define LM78_IN1_MIN 0x2e
#define LM78_IN2_MAX 0x2f
#define LM78_IN2_MIN 0x30
#define LM78_IN3_MAX 0x31
#define LM78_IN3_MIN 0x32
#define LM78_IN4_MAX 0x33
#define LM78_IN4_MIN 0x34
#define LM78_IN5_MAX 0x35
#define LM78_IN5_MIN 0x36
#define LM78_IN6_MAX 0x37
#define LM78_IN6_MIN 0x38
#define LM78_TEMPERATURE_MAX 0x39
#define LM78_TEMPERATURE_MIN 0x3a
#define LM78_FAN1_MAX 0x3b
#define LM78_FAN2_MAX 0x3c
#define LM78_FAN3_MAX 0x3d

/* addresses of LM78 registers */
#define LM78_VID 0x47
#define LM78_INTSTAT1 0x41
#define LM78_INTSTAT2 0x42
#define LM78_CONFIG 0x40
#define LM78_FANDIV 0x47
#define LM78_SMBUSADDR 0x48
#define LM78_RESET 0x49

/* Calculate rpms from tacho-count */
#define LM78_RPM(count,div) (1350000/(count*div))

/* string constants */
#define LM78_FAN1_STRING   "Fan1"
#define LM78_FAN2_STRING   "Fan2"
#define LM78_FAN3_STRING   "Fan3"

/* Currently, this has no function. One day, we may have different defines
   for different mainboards */
#define LM78_ASUS_TX97 1
#define LM78_TYAN_S1832DL 0

#if (LM78_ASUS_TX97 || LM78_TYAN_S1832DL)
# define LM78_IN0_STRING "Vcore"
# define LM78_IN1_STRING "Vcore2"
# define LM78_IN2_STRING "+3.3V"
# define LM78_IN3_STRING "+5V"
# define LM78_IN4_STRING "+12V"
# define LM78_IN5_STRING "-12V"
# define LM78_IN6_STRING "-5V"

/* Here follow the normalization factors for the voltage levels.
   These are ratios suggested by the National Semi docs:
   Suggested +5V ratio (NORMAL_3) 1.6778523
   Suggested +12V ratio (NORMAL_4) 4.0
   Suggested -12V ratio (NORMAL_5) 4.0
   Suggested -5V ratio (NORMAL_6) 1.6666667 
   Note that these are multiplied with 10000, to keep floating point
   operation out of the kernel. */
#define NORMAL_IN0 10000
#define NORMAL_IN1 10000
#define NORMAL_IN2 10000
#define NORMAL_IN3 16523
#define NORMAL_IN4 38552
#define NORMAL_IN5 -35484
#define NORMAL_IN6 -15268

#endif

#endif /* LM78_H */

