
/*
    SMBus.h - Part of a Linux module for reading sensor data.
    Copyright (c) 1998  Philip Edelbrock <phil@netroedge.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef SMBUS_H
#define SMBUS_H

/*
	Prototypes 
*/
extern int Init_SMBus(void);
extern void Cleanup_SMBus(void);
extern int write_smbus(int addr, long value, int size);
extern int read_smbus(int addr, int command, int size);

/*
	I/O Space Constants
*/
#define SMBHSTSTS PIIX4_smba
#define SMBHSLVSTS PIIX4_smba + 1
#define SMBHSTCNT PIIX4_smba + 2
#define SMBHSTCMD PIIX4_smba + 3
#define SMBHSTADD PIIX4_smba + 4
#define SMBHSTDAT0 PIIX4_smba + 5
#define SMBHSTDAT1 PIIX4_smba + 6

/*
	PCI Address Constants
*/
#define SMBBA     0x090
#define SMBHSTCFG 0x0D2
#define SMBSLVC   0x0D3
#define SMBSHDW1  0x0D4
#define SMBSHDW2  0x0D5
#define SMBREV    0x0D6

/*
	Contants for other uses
*/
#define MAX_TIMEOUT 500


/* Set to 1 to enable (don't comment out completely)
   This is known to freeze some machines (as Frodo knows ;')
   in the current implemented state, so beware! */
#define  ENABLE_INT9 0

/* SMBus transaction types */
#define QUICK_READ 0x00
#define BYTE       0x04
#define BYTE_DATA  0x08 
#define WORD_DATA  0x0C
#define BLOCK_DATA 0x14

/* This useful macro is not defined in the 2.0 kernels */
#ifndef KERNEL_VERSION
#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#endif

/* pci_present is not defined for 2.0 kernels; perhaps some early 2.1
   kernels do not have it either? */
#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,1,0))
#define pci_present pcibios_present
#endif

/* mdelay is not defined for 2.0 kernels; perhaps some early 2.1 kernels
   do no have it either? */
#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,1,0))
#define MAX_UDELAY_MS   5
#define mdelay(n) (\
        (__builtin_constant_p(n) && (n)<=MAX_UDELAY_MS) ? udelay((n)*1000) : \
        ({unsigned long msec=(n); while (msec--) udelay(1000);}))
#endif

#endif /* SMBUS_H */
